@@ -34,7 +34,7 @@ def Increment(new, mirror, incpref):
 
 	"""
 	log.Log("Incrementing mirror file " + mirror.path, 5)
-	if ((new and new.isdir()) or mirror.isdir()) and not incpref.isdir():
+	if ((new and new.isdir()) or mirror.isdir()) and not incpref.lstat():
 		incpref.mkdir()
 
 	if not mirror.lstat(): incrp = makemissing(incpref)
@@ -111,7 +111,7 @@ def get_inc(rp, typestr, time = None):
 	else:
 		dirname, basename = rp.dirsplit()
 		incrp = rp.__class__(rp.conn, dirname, (addtostr(basename),))
-	assert not incrp.lstat()
+	assert not incrp.lstat(), incrp
 	return incrp
 
 
